Index: TXM/trunk/org.txm.core/src/java/org/txm/core/messages/messages_fr.properties
===================================================================
--- TXM/trunk/org.txm.core/src/java/org/txm/core/messages/messages_fr.properties	(revision 3437)
+++ TXM/trunk/org.txm.core/src/java/org/txm/core/messages/messages_fr.properties	(revision 3438)
@@ -4,7 +4,7 @@
 
 ToolboxStatesWorkspaceColonP0 = \ Espace de travail : {0}
 
-binaryDirectoryP0NotFound = Impossible de trouver le répertoire de corpus binaire {0}.
+binaryDirectoryP0NotFound = Impossible de trouver le dossier de corpus binaire {0}.
 
 cQiClientNotInitialized = ** Le client CQi n'est pas initialisé
 
Index: TXM/trunk/org.txm.translate.rcp/messages_fr.properties
===================================================================
--- TXM/trunk/org.txm.translate.rcp/messages_fr.properties	(revision 3437)
+++ TXM/trunk/org.txm.translate.rcp/messages_fr.properties	(revision 3438)
@@ -262,7 +262,7 @@
 cooccurrence.rcp.messages.CooccurrenceUI.theScoreThresholdMustBeARealNumberCurrentValueEqualsP0=Le seuil d''indice doit être un nombre réel (la valeur actuelle est {0})
 cooccurrence.rcp.messages.CooccurrenceUI.thresholdsColonFmin=Seuils \: Fmin ≥
 cooccurrence.rcp.messages.CooccurrenceUI.usePartialLexicalTable=Calculer les marges à partir des fréquences des cooccurents plutôt qu'à partir des fréquences de tous les mots du corpus
-core.messages.TXMCore.binaryDirectoryP0NotFound=Impossible de trouver le répertoire de corpus binaire {0}.
+core.messages.TXMCore.binaryDirectoryP0NotFound=Impossible de trouver le dossier de corpus binaire {0}.
 core.messages.TXMCore.cantFindStructuralUnitForMetadataWithIdColon=** Erreur \: pas de structures trouvées pour la métadonnée d'identifiant 
 core.messages.TXMCore.catalogFileNotFoundP0=** Fichier de catalogue introuvable {0}.
 core.messages.TXMCore.checkingBinaryFormat=Vérification du format du corpus binaire…
@@ -742,7 +742,7 @@
 rcp.messages.TXMUI.eRROR=\ ERREUR 
 rcp.messages.TXMUI.error_invalidRegularExpression=Expression régulière incorrecte \: {0}
 rcp.messages.TXMUI.errorColonCorporaDirectoryDoesntExistColon=** Erreur\: le dossier 'corpora' n'existe pas \: 
-rcp.messages.TXMUI.errorColonCurrentGroovyScriptDirectoryDoesNotExistColon=** Erreur \: le répertoire du script Groovy courant n'existe pas \: 
+rcp.messages.TXMUI.errorColonCurrentGroovyScriptDirectoryDoesNotExistColon=** Erreur \: le dossier du script Groovy courant n'existe pas \: 
 rcp.messages.TXMUI.errorColonDeleteReturnedFalse=** Erreur lors de la suppression
 rcp.messages.TXMUI.errorColonElementNotRegistered=** Erreur \: élément non enregistré 
 rcp.messages.TXMUI.errorColonGetTextColonP0=** Erreur interne \: getText {0}
@@ -848,7 +848,7 @@
 rcp.messages.TXMUI.infpSupTXMIsPublishedUnderTheGNUGPL2LicenseAmpltInfaHrefEqualshttpsColonwwwgnuorglicensesgpl20enhtmlSuphttpsColonwwwgnuorglicensesgpl20enhtmlInfaSupAmpgt=<p>TXM est diffusé sous la licence GNU GPL 2 &lt;<a href\="https\://www.gnu.org/licenses/gpl-2.0.fr.html">https\://www.gnu.org/licenses/gpl-2.0.fr.html</a>&gt;.</p>
 rcp.messages.TXMUI.initializationOfThePlatform=Initialisation de la plateforme…
 rcp.messages.TXMUI.initializingPlatform=Initialisation de la plateforme…
-rcp.messages.TXMUI.installingPreviousCorpusFromP0=Récupération des corpus préexistants de TXM {0} (depuis le répertoire {1})...
+rcp.messages.TXMUI.installingPreviousCorpusFromP0=Récupération des corpus préexistants de TXM {0} (depuis le dossier {1})...
 rcp.messages.TXMUI.installingSampleCorpus=Installation des corpus exemples...
 rcp.messages.TXMUI.installPathColonP0=Chemin d''installation \: {0}.
 rcp.messages.TXMUI.integer=Entier
@@ -993,13 +993,13 @@
 rcp.messages.TXMUI.seeTheQuoteSectionIn=(voir la section 'Citer le logiciel TXM' de la page d'accueil du site 
 rcp.messages.TXMUI.select=Sélectionner
 rcp.messages.TXMUI.selectACompositeSorter=Sélectionner un tri multiple
-rcp.messages.TXMUI.selectAnotherTXMCorporaToRestore=Sélectionner un autre répertoire "corpora" de corpus à récupérer...
+rcp.messages.TXMUI.selectAnotherTXMCorporaToRestore=Sélectionner un autre dossier "corpora" de corpus à récupérer...
 rcp.messages.TXMUI.selectAProperty=Sélectionner une propriété
 rcp.messages.TXMUI.selectColon=Sélectionner \:
 rcp.messages.TXMUI.selectionIsNotACorpusColon=L'objet sélectionné n'est pas un corpus \: 
 rcp.messages.TXMUI.selectTextId=Sélectionner un texte
 rcp.messages.TXMUI.selectThecorporaSetsToRestore=Sélectionnez les corpus à restaurer
-rcp.messages.TXMUI.selectTheSourceDirectory=Sélectionner le répertoire des fichiers sources
+rcp.messages.TXMUI.selectTheSourceDirectory=Sélectionner le dossier des fichiers sources
 rcp.messages.TXMUI.selectValuesToAssignColon=Sélectionner les valeurs à affecter \: 
 rcp.messages.TXMUI.selectWorkingDirectory=Répertoire de travail
 rcp.messages.TXMUI.separatedByAtLeast0Word=séparé par au moins 0 mot
@@ -1050,8 +1050,8 @@
 rcp.messages.TXMUI.theFileP0DoesNotExist=Le fichier {0} est introuvable.
 rcp.messages.TXMUI.theInputP0CannotBeDisplayed=** Erreur interne \: Impossible d''afficher la donnée {0}.
 rcp.messages.TXMUI.theNumberOfEditorsP0AndNumberOfInputsP1MustBeEqual=** Erreur interne \: le nombre d''éditeurs RCP ({0}) doit correspondre au nombre d''inputs ({1}).
-rcp.messages.TXMUI.theP0CorpusDirectoryAlreadyExistsDoYouWantToReplaceIt=Le répertoire de corpus {0} existe déjà. Voulez-vous le remplacer ?
-rcp.messages.TXMUI.theP0directoryNotABinaryCorpus=Le répertoire {0} n'est pas un corpus binaire.
+rcp.messages.TXMUI.theP0CorpusDirectoryAlreadyExistsDoYouWantToReplaceIt=Le dossier de corpus {0} existe déjà. Voulez-vous le remplacer ?
+rcp.messages.TXMUI.theP0directoryNotABinaryCorpus=Le dossier {0} n'est pas un corpus binaire.
 rcp.messages.TXMUI.theP1GroovyScriptMustBeInTheP0Folder=Le script Groovy {1} doit être dans le dossier {0}.
 rcp.messages.TXMUI.theTableMustContainAtLeastOneLine=Le tableau doit comporter au moins une ligne
 rcp.messages.TXMUI.theTwoArraysMustHaveTheSameSize=Les deux tableaux doivent être de même taille.
Index: TXM/trunk/org.txm.translate.rcp/messages2_fr.properties
===================================================================
--- TXM/trunk/org.txm.translate.rcp/messages2_fr.properties	(revision 3437)
+++ TXM/trunk/org.txm.translate.rcp/messages2_fr.properties	(revision 3438)
@@ -2,7 +2,7 @@
 #Thu Dec 06 12:41:34 CET 2018
 chartsengine.core.messages.ChartsEngineCore.error_cantCreateTmpChartFileP0=** Impossible de créer le fichier temporaire du graphique {0}
 rcp.messages.TXMUI.leftContextSize=Taille du contexte gauche
-rcp.messages.TXMUI.theP0CorpusDirectoryAlreadyExistsDoYouWantToReplaceIt=Le répertoire de corpus {0} existe déjà. Voulez-vous le remplacer ?
+rcp.messages.TXMUI.theP0CorpusDirectoryAlreadyExistsDoYouWantToReplaceIt=Le dossier de corpus {0} existe déjà. Voulez-vous le remplacer ?
 rcp.messages.TXMUI.parameters=Paramètres
 core.messages.TXMCore.isNotAValidCQPIdForASubcorpusItMustBeAnUppercaseCharactersFollowedByLowercaseCharacters=\ n''est pas un identifiant de sous-corpus CQP valide. Il doit être en majuscules suivies de caractères minuscules.
 core.messages.TXMCore.print2=/ {print $2}''`
@@ -466,7 +466,7 @@
 rcp.messages.TXMUI.cannotReadTheFileP0=** Impossible de lire le fichier {0}.
 properties.core.messages.PropertiesCore.RESULT_TYPE=Propriétés
 rcp.messages.TXMUI.startJobColonCheckTXMHOME=Démarrage \: vérification de TXMHOME
-core.messages.TXMCore.isADirectory=est un répertoire
+core.messages.TXMCore.isADirectory=est un dossier
 rcp.messages.TXMUI.dDotMandatoryField=* \: champ obligatoire
 properties.core.messages.PropertiesCore.descriptionOf=Détails du corpus  
 referencer.rcp.messages.ReferencerUI.showingNextResultPage=Affichage de la page de résultats suivante 
@@ -811,7 +811,7 @@
 rcp.messages.TXMUI.restartTXM=Redémarrer TXM
 rcp.messages.TXMUI.moduleUIParametersColonP0=Paramètres de l''interface utilisateur du module \: {0}
 ca.rcp.messages.CAUI.canNotComputeFactorialAnalysisWithOnlyP0PartsTheMinimumIs4Parts=** Impossible de calculer l''analyse factorielle avec seulement {0} parties (le minimum est de 4 parties).
-rcp.messages.TXMUI.selectTheSourceDirectory=Sélectionner le répertoire des fichiers sources
+rcp.messages.TXMUI.selectTheSourceDirectory=Sélectionner le dossier des fichiers sources
 rcp.messages.TXMUI.execColon=Exec \: {0}.
 rcp.messages.TXMUI.theErrorIsColon=L''erreur est \:  
 cooccurrence.rcp.messages.CooccurrenceUI.score=Indice
@@ -973,7 +973,7 @@
 annotation.kr.rcp.messages.KRAnnotationUI.errorWhileDeletingAnnotationColonP0=** Erreur lors de la suppression de l’annotation \: {0}
 rcp.messages.TXMUI.deletedColonP0={0} supprimé.
 rcp.messages.TXMUI.newMacro=Nouvelle macro
-core.messages.TXMCore.binaryDirectoryP0NotFound=Impossible de trouver le répertoire de corpus binaire {0}.
+core.messages.TXMCore.binaryDirectoryP0NotFound=Impossible de trouver le dossier de corpus binaire {0}.
 statsengine.core.messages.StatsEngineCore.columnIndex=Index de colonne (
 statsengine.r.core.messages.RCore.info_rPathNotSetTryingToFindIt=Chemin d''accès à l’exécutable de R non indiqué, recherche de l’exécutable dans des lieux standards…
 rcp.messages.TXMUI.FileTreeContentProvider_4=''
@@ -1061,7 +1061,7 @@
 rcp.messages.TXMUI.Explorer_5=⭮
 rcp.messages.TXMUI.Explorer_7=⌂
 rcp.messages.TXMUI.lexicon=Lexique
-rcp.messages.TXMUI.errorColonCurrentGroovyScriptDirectoryDoesNotExistColon=** Erreur \: le répertoire du script Groovy courant n’existe pas \: 
+rcp.messages.TXMUI.errorColonCurrentGroovyScriptDirectoryDoesNotExistColon=** Erreur \: le dossier du script Groovy courant n’existe pas \: 
 progression.core.messages.ProgressionCore.RESULT_TYPE=Progression
 core.messages.TXMCore.parentDirectoryP0NotFound=Dossier parent ‘’{0}’ introuvable.
 statsengine.r.core.messages.RCore.info_connectingToRAtWithUser=Connexion à R à l’adresse {0}\:{1} avec l''utilisateur {2}.
Index: TXM/trunk/org.txm.translate.rcp/bundle_fr.properties
===================================================================
--- TXM/trunk/org.txm.translate.rcp/bundle_fr.properties	(revision 3437)
+++ TXM/trunk/org.txm.translate.rcp/bundle_fr.properties	(revision 3438)
@@ -113,7 +113,7 @@
 rcp.messages.TXMUI.command.label.100=Trouver précédent
 rcp.messages.TXMUI.command.label.101=Graphique...
 rcp.messages.TXMUI.command.label.109=Recherche incrémentale
-rcp.messages.TXMUI.command.label.11=un répertoire de corpus binaires....
+rcp.messages.TXMUI.command.label.11=un dossier de corpus binaires....
 rcp.messages.TXMUI.command.label.110=Recherche incrémentale (inverse)
 rcp.messages.TXMUI.command.label.113=Aller à la ligne...
 rcp.messages.TXMUI.command.label.12=XML-TEI TXM
@@ -303,9 +303,9 @@
 rcp.messages.TXMUI.command.tooltip.25=Importer un corpus au format CQP
 rcp.messages.TXMUI.command.tooltip.26=Redémarrer TXM
 rcp.messages.TXMUI.command.tooltip.27=Importer un corpus depuis le presse-papier
-rcp.messages.TXMUI.command.tooltip.28=Importer un répertoire de corpus au format CNR associé à un fichier de métadonnées
-rcp.messages.TXMUI.command.tooltip.29=Importer un répertoire de corpus au format Hyperbase
-rcp.messages.TXMUI.command.tooltip.30=Importer un répertoire de corpus au format Alceste
+rcp.messages.TXMUI.command.tooltip.28=Importer un dossier de corpus au format CNR associé à un fichier de métadonnées
+rcp.messages.TXMUI.command.tooltip.29=Importer un dossier de corpus au format Hyperbase
+rcp.messages.TXMUI.command.tooltip.30=Importer un dossier de corpus au format Alceste
 rcp.messages.TXMUI.command.tooltip.31=Afficher les caractères non imprimables
 rcp.messages.TXMUI.command.tooltip.33=Supprimer l'objet sélectionné
 rcp.messages.TXMUI.command.tooltip.34=Éditer un nouveau fichier
Index: TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/InstallAndUpdateMacrosMacro.groovy
===================================================================
--- TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/InstallAndUpdateMacrosMacro.groovy	(revision 3437)
+++ TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/InstallAndUpdateMacrosMacro.groovy	(revision 3438)
@@ -9,7 +9,7 @@
 }
 
 if (!groovyUserDirectory.exists()) {
-	monitorShowError("Le répertoire $groovyUserDirectory n'a pas pu être créé. Abandon.")
+	monitorShowError("Le dossier $groovyUserDirectory n'a pas pu être créé. Abandon.")
 	return;
 }
 @Field @Option(name="macroPaths", usage="Comma separated list of macro paths", widget="String", required=true, def="/")
Index: TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/table/ExcelDir2XMLMacro.groovy
===================================================================
--- TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/table/ExcelDir2XMLMacro.groovy	(revision 3437)
+++ TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/table/ExcelDir2XMLMacro.groovy	(revision 3438)
@@ -14,7 +14,7 @@
 import org.apache.poi.ss.usermodel.WorkbookFactory
 import org.apache.poi.ss.util.*
 
-@Field @Option(name="inputDirectory", usage="répertoire des fichiers Excel à traiter", widget="Folder", required=true, def="")
+@Field @Option(name="inputDirectory", usage="dossier des fichiers Excel à traiter", widget="Folder", required=true, def="")
 def inputDirectory
 
 @Field @Option(name="sheetName", usage="sheet name (if no name is given the first sheet will be used)", widget="String", required=false, def="")
Index: TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/projects/antract/InstallerEtMettreAJourOutilsMacro.groovy
===================================================================
--- TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/projects/antract/InstallerEtMettreAJourOutilsMacro.groovy	(revision 3437)
+++ TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/projects/antract/InstallerEtMettreAJourOutilsMacro.groovy	(revision 3438)
@@ -10,7 +10,7 @@
 }
 
 if (!groovyUserDirectory.exists()) {
-	monitorShowError("Le répertoire $groovyUserDirectory n'a pas pu être créé. Abandon.")
+	monitorShowError("Le dossier $groovyUserDirectory n'a pas pu être créé. Abandon.")
 	return;
 }
 
Index: TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/edition/RebuildTRSEditionMacro.groovy
===================================================================
--- TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/edition/RebuildTRSEditionMacro.groovy	(revision 3437)
+++ TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/edition/RebuildTRSEditionMacro.groovy	(revision 3438)
@@ -44,7 +44,7 @@
 
 // Les paramètres dont on a besoin :
 // Nom du Corpus dans TXM on le récupère de l amême façon que EditionUpdaterMacro...
-// Nom du répertoire dans lequel sont les trs utilisables avec transcriber (i.e. ceux à partir desquels on trouve les fichiers sons).
+// Nom du dossier dans lequel sont les trs utilisables avec transcriber (i.e. ceux à partir desquels on trouve les fichiers sons).
 // Nom de l'édition à modifier.
 
 
Index: TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/office/MergeExcelDirMacro.groovy
===================================================================
--- TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/office/MergeExcelDirMacro.groovy	(revision 3437)
+++ TXM/trunk/org.txm.groovy.core/src/groovy/org/txm/macro/office/MergeExcelDirMacro.groovy	(revision 3438)
@@ -17,7 +17,7 @@
 import org.apache.poi.xssf.usermodel.*
 import org.apache.poi.ss.util.*
 
-@Field @Option(name="inputDirectory", usage="répertoire des fichiers Excel à fusionner", widget="Folder", required=true, def="")
+@Field @Option(name="inputDirectory", usage="dossier des fichiers Excel à fusionner", widget="Folder", required=true, def="")
 def inputDirectory
 
 @Field @Option(name="outputFile", usage="output file", widget="FileSave", required=true, def="")
Index: TXM/trunk/org.txm.utils/src/org/txm/utils/zip/Zip.java
===================================================================
--- TXM/trunk/org.txm.utils/src/org/txm/utils/zip/Zip.java	(revision 3437)
+++ TXM/trunk/org.txm.utils/src/org/txm/utils/zip/Zip.java	(revision 3438)
@@ -234,7 +234,7 @@
 		entry.setTime(file.lastModified());
 		out.putNextEntry(entry);
 
-		// Traitement récursif s'il s'agit d'un répertoire
+		// Traitement récursif s'il s'agit d'un dossier
 		// System.out.println("COMPRESS "+file+" monitor="+monitor);
 		if (file.isDirectory()) {
 			File[] files = file.listFiles();
Index: TXM/trunk/org.txm.analec.rcp/src matt/visuAnalec/fichiers/FichiersJava.java
===================================================================
--- TXM/trunk/org.txm.analec.rcp/src matt/visuAnalec/fichiers/FichiersJava.java	(revision 3437)
+++ TXM/trunk/org.txm.analec.rcp/src matt/visuAnalec/fichiers/FichiersJava.java	(revision 3438)
@@ -23,7 +23,7 @@
 					"Choix du document", Fichiers.TypeFichier.DOC_ANALEC))==null) return;
 		} else {
 			if ((fichierCorpus = Fichiers.trouverFichier(Fichiers.TypeFichier.DOC_ANALEC, nomfichier))==null) {
-				JOptionPane.showMessageDialog(null, "Fichier "+nomfichier+" inexistant dans le répertoire "
+				JOptionPane.showMessageDialog(null, "Fichier "+nomfichier+" inexistant dans le dossier "
 						+Fichiers.getRepertoireCourant(Fichiers.TypeFichier.DOC_ANALEC).getPath(), "Erreur de lecture de fichier",
 						JOptionPane.ERROR_MESSAGE);
 				return;
@@ -197,7 +197,7 @@
 
 	public static void concatenerCorpus(final Corpus corpus) {
 		File rep;
-		if ((rep = Fichiers.choisirRepertoire("Choix du répertoire à concaténer"))
+		if ((rep = Fichiers.choisirRepertoire("Choix du dossier à concaténer"))
 				==null) return;
 		final File[] fics = Fichiers.listerFichiers(rep, Fichiers.TypeFichier.DOC_ANALEC);
 		final GMessages.GProgression progression =
@@ -218,7 +218,7 @@
 
 	public static void extraireTypeCorpus(final String type, final Corpus corpus) {
 		File rep;
-		if ((rep = Fichiers.choisirRepertoire("Choix du répertoire à traiter"))==null) return;
+		if ((rep = Fichiers.choisirRepertoire("Choix du dossier à traiter"))==null) return;
 		final  File[] fics = Fichiers.listerFichiers(rep, Fichiers.TypeFichier.DOC_ANALEC);
 		final GMessages.GProgression progression =
 				new GMessages.GProgression(fics.length, "Extraction", "fichiers");
Index: TXM/trunk/org.txm.analec.rcp/src matt/visuAnalec/fichiers/FichiersTEI.java
===================================================================
--- TXM/trunk/org.txm.analec.rcp/src matt/visuAnalec/fichiers/FichiersTEI.java	(revision 3437)
+++ TXM/trunk/org.txm.analec.rcp/src matt/visuAnalec/fichiers/FichiersTEI.java	(revision 3438)
@@ -31,13 +31,13 @@
 		if ((ficTEI = Fichiers.choisirFichier(Commande.OUVRIR,
 				"Choix du fichier corpus TEI", TypeFichier.TEI))==null)
 			return;
-		if ((repJava = Fichiers.choisirRepertoire("Choix du répertoire Java"))==null)
+		if ((repJava = Fichiers.choisirRepertoire("Choix du dossier Java"))==null)
 			return;
 		if (!repJava.exists()) {
-			if (!GMessages.confirmationAction("Le répertoire spécifié n'existe pas."
+			if (!GMessages.confirmationAction("Le dossier spécifié n'existe pas."
 					+" Voulez-vous le créer ?")) return;
 			if (!repJava.mkdir()) {
-				GMessages.impossibiliteAction("Echec de la création du répertoire");
+				GMessages.impossibiliteAction("Echec de la création du dossier");
 				return;
 			}
 		}
@@ -48,7 +48,7 @@
 		String nomTEI = Fichiers.extraireNom(ficTEI)+"-";
 		if (Fichiers.existeDebutFichier(repJava, TypeFichier.DOC_ANALEC, nomTEI))
 			if (!GMessages.confirmationAction("Attention! Certains fichiers du "
-					+"répertoire "+repJava.getName()
+					+"dossier "+repJava.getName()
 					+" risquent d'être écrasés")) return;
 		try {
 			tei = new BufferedInputStream(
@@ -483,7 +483,7 @@
 	public static boolean exporterCorpusTEI(final Corpus corpus) {
 		File repJava;
 		final File ficTEI;
-		final File[] fics = Fichiers.choisirCorpus("Choix du répertoire Java",
+		final File[] fics = Fichiers.choisirCorpus("Choix du dossier Java",
 				TypeFichier.CORPUS_ANALEC);
 		if (fics.length==0) return false;
 
Index: TXM/trunk/org.txm.analec.rcp/src matt/visuAnalec/fichiers/FichiersGlozz.java
===================================================================
--- TXM/trunk/org.txm.analec.rcp/src matt/visuAnalec/fichiers/FichiersGlozz.java	(revision 3437)
+++ TXM/trunk/org.txm.analec.rcp/src matt/visuAnalec/fichiers/FichiersGlozz.java	(revision 3438)
@@ -22,15 +22,15 @@
 	public static void convertirCorpusGlozz(final Corpus corpus) {
 		File repGlozz;
 		final File repJava;
-		if ((repGlozz = Fichiers.choisirRepertoire("Choix du répertoire Glozz"))==null)
+		if ((repGlozz = Fichiers.choisirRepertoire("Choix du dossier Glozz"))==null)
 			return;
-		if ((repJava = Fichiers.choisirRepertoire("Choix du répertoire Java"))==null)
+		if ((repJava = Fichiers.choisirRepertoire("Choix du dossier Java"))==null)
 			return;
 		if (!repJava.exists()) {
-			if (!GMessages.confirmationAction("Le répertoire spécifié n'existe pas."
+			if (!GMessages.confirmationAction("Le dossier spécifié n'existe pas."
 					+" Voulez-vous le créer ?")) return;
 			if (!repJava.mkdir()) {
-				GMessages.impossibiliteAction("Echec de la création du répertoire");
+				GMessages.impossibiliteAction("Echec de la création du dossier");
 				return;
 			}
 		}
Index: TXM/trunk/org.txm.analec.rcp/src/org/txm/annotation/urs/messages_fr.properties
===================================================================
--- TXM/trunk/org.txm.analec.rcp/src/org/txm/annotation/urs/messages_fr.properties	(revision 3437)
+++ TXM/trunk/org.txm.analec.rcp/src/org/txm/annotation/urs/messages_fr.properties	(revision 3438)
@@ -13,7 +13,7 @@
 
 DoInstallStep_11 = Les macro URS précédentes ont été déplacée à {0}
 
-DoInstallStep_17 = ** Erreur lors de la copie du répertoire de macro "org/txm/macro/urs" dans {0}
+DoInstallStep_17 = ** Erreur lors de la copie du dossier de macro "org/txm/macro/urs" dans {0}
 
 DoInstallStep_18 = URS post-installation terminé.
 
@@ -23,7 +23,7 @@
 
 DoInstallStep_6 = Post-installing URS version={0}
 
-DoInstallStep_9 = Le répertoire de backup existe déjà : {0}
+DoInstallStep_9 = Le dossier de backup existe déjà : {0}
 
 EditStructure_0 = La sélection n'est pas un corpus : {0}
 
@@ -63,9 +63,9 @@
 
 ImportGlozzAnnotations_9 = Enregistrement des annotations.
 
-ImportGlozzCorpus_0 = Le répertoire {0} glozz doit exister.
+ImportGlozzCorpus_0 = Le dossier {0} glozz doit exister.
 
-ImportGlozzCorpus_1 = Création du répertoire source {0}.
+ImportGlozzCorpus_1 = Création du dossier source {0}.
 
 ImportGlozzCorpus_10 = Le nombre de fichier aa est différent du nombre de fichier ac dans {0}.
 
@@ -93,19 +93,19 @@
 
 ImportGlozzCorpus_29 = Enregistrement des annotations...
 
-ImportGlozzCorpus_3 = Création du répertoire ec: {0}.
+ImportGlozzCorpus_3 = Création du dossier ec: {0}.
 
 ImportGlozzCorpus_30 = Terminé.
 
 ImportGlozzCorpus_32 = Erreur lors de la finalisation de l'import du corpus : {0}
 
-ImportGlozzCorpus_4 = Le répertoire {0} des sources n'a pu être créé.
+ImportGlozzCorpus_4 = Le dossier {0} des sources n'a pu être créé.
 
-ImportGlozzCorpus_5 = Le répertoire ec {0} n''a pu être créé
+ImportGlozzCorpus_5 = Le dossier ec {0} n''a pu être créé
 
-ImportGlozzCorpus_8 = Pas de fichier .aa trouvé dans le répertoire {0}
+ImportGlozzCorpus_8 = Pas de fichier .aa trouvé dans le dossier {0}
 
-ImportGlozzCorpus_9 = Pas de fichier .ac trouvé dans le répertoire {0}
+ImportGlozzCorpus_9 = Pas de fichier .ac trouvé dans le dossier {0}
 
 ImportTEIAnnotations_0 = La sélection n''est pas un corpus : {0}
 
@@ -131,7 +131,7 @@
 
 ImportTEICorpus_19 = Erreur lors de l'import du modèle d'annotation TEI.
 
-ImportTEICorpus_2 = Creation du répertoire source : {0}
+ImportTEICorpus_2 = Creation du dossier source : {0}
 
 ImportTEICorpus_20 = Réindexation des annotations avec les mots TXM.
 
@@ -143,7 +143,7 @@
 
 ImportTEICorpus_24 = Erreur lors de la finalisation de l''import du corpus : {0}
 
-ImportTEICorpus_3 = ** Le répertoire source {0} n''a pas pu être créé 
+ImportTEICorpus_3 = ** Le dossier source {0} n''a pas pu être créé 
 
 ImportTEICorpus_5 = Import des données TEI depuis : {0}
 
Index: TXM/trunk/org.txm.analec.rcp/src/visuAnalec/chaines/ExportCSV.java
===================================================================
--- TXM/trunk/org.txm.analec.rcp/src/visuAnalec/chaines/ExportCSV.java	(revision 3437)
+++ TXM/trunk/org.txm.analec.rcp/src/visuAnalec/chaines/ExportCSV.java	(revision 3438)
@@ -184,7 +184,7 @@
       }
   }
   /*ajouté probablement dans la mauvaise classe, la package fichier semble plus adapté pour recevoir les classes*/
-  /*ici on laisse l'utilisateur choisir un répertoire où enregistrer*/
+  /*ici on laisse l'utilisateur choisir un dossier où enregistrer*/
   public static void writeChartToPDF(ChartPanel chart,int width,int height) {
     String fileName="";
     
Index: TXM/trunk/org.txm.analec.rcp/src/visuAnalec/fichiers/FichiersJava.java
===================================================================
--- TXM/trunk/org.txm.analec.rcp/src/visuAnalec/fichiers/FichiersJava.java	(revision 3437)
+++ TXM/trunk/org.txm.analec.rcp/src/visuAnalec/fichiers/FichiersJava.java	(revision 3438)
@@ -25,7 +25,7 @@
               "Choix du document", Fichiers.TypeFichier.DOC_ANALEC))==null) return;
     } else {
       if ((fichierCorpus = Fichiers.trouverFichier(Fichiers.TypeFichier.DOC_ANALEC, nomfichier))==null) {
-        JOptionPane.showMessageDialog(null, "Fichier "+nomfichier+" inexistant dans le répertoire "
+        JOptionPane.showMessageDialog(null, "Fichier "+nomfichier+" inexistant dans le dossier "
                 +Fichiers.getRepertoireCourant(Fichiers.TypeFichier.DOC_ANALEC).getPath(), "Erreur de lecture de fichier",
                 JOptionPane.ERROR_MESSAGE);
         return;
@@ -201,7 +201,7 @@
 
   public static void concatenerCorpus(final Corpus corpus) {
     File rep;
-    if ((rep = Fichiers.choisirRepertoire("Choix du répertoire à concaténer"))
+    if ((rep = Fichiers.choisirRepertoire("Choix du dossier à concaténer"))
             ==null) return;
     final File[] fics = Fichiers.listerFichiers(rep, Fichiers.TypeFichier.DOC_ANALEC);
     final GMessages.GProgression progression =
@@ -222,7 +222,7 @@
 
   public static void extraireTypeCorpus(final String type, final Corpus corpus) {
     File rep;
-    if ((rep = Fichiers.choisirRepertoire("Choix du répertoire à traiter"))
+    if ((rep = Fichiers.choisirRepertoire("Choix du dossier à traiter"))
             ==null) return;
    final  File[] fics = Fichiers.listerFichiers(rep, Fichiers.TypeFichier.DOC_ANALEC);
     final GMessages.GProgression progression =
Index: TXM/trunk/org.txm.analec.rcp/src/visuAnalec/fichiers/FichiersTEI.java
===================================================================
--- TXM/trunk/org.txm.analec.rcp/src/visuAnalec/fichiers/FichiersTEI.java	(revision 3437)
+++ TXM/trunk/org.txm.analec.rcp/src/visuAnalec/fichiers/FichiersTEI.java	(revision 3438)
@@ -31,13 +31,13 @@
     if ((ficTEI = Fichiers.choisirFichier(Commande.OUVRIR,
             "Choix du fichier corpus TEI", TypeFichier.TEI))==null)
       return;
-    if ((repJava = Fichiers.choisirRepertoire("Choix du répertoire Java"))==null)
+    if ((repJava = Fichiers.choisirRepertoire("Choix du dossier Java"))==null)
       return;
     if (!repJava.exists()) {
-      if (!GMessages.confirmationAction("Le répertoire spécifié n'existe pas."
+      if (!GMessages.confirmationAction("Le dossier spécifié n'existe pas."
               +" Voulez-vous le créer ?")) return;
       if (!repJava.mkdir()) {
-        GMessages.impossibiliteAction("Echec de la création du répertoire");
+        GMessages.impossibiliteAction("Echec de la création du dossier");
         return;
       }
     }
@@ -49,7 +49,7 @@
     String nomTEI = Fichiers.extraireNom(ficTEI)+"-";
     if (Fichiers.existeDebutFichier(repJava, TypeFichier.DOC_ANALEC, nomTEI))
       if (!GMessages.confirmationAction("Attention! Certains fichiers du "
-              +"répertoire "+repJava.getName()
+              +"dossier "+repJava.getName()
               +" risquent d'être écrasés")) return false;
     try {
       tei = new BufferedInputStream(
@@ -485,7 +485,7 @@
   public static boolean exporterCorpusTEI(final Corpus corpus) {
     File repJava;
     final File ficTEI;
-    final File[] fics = Fichiers.choisirCorpus("Choix du répertoire Java",
+    final File[] fics = Fichiers.choisirCorpus("Choix du dossier Java",
             TypeFichier.CORPUS_ANALEC);
     if (fics.length==0) return false; ;
     final HashMap<String, String> infosCorpus = new HashMap<String, String>();
Index: TXM/trunk/org.txm.analec.rcp/src/visuAnalec/fichiers/FichiersGlozz.java
===================================================================
--- TXM/trunk/org.txm.analec.rcp/src/visuAnalec/fichiers/FichiersGlozz.java	(revision 3437)
+++ TXM/trunk/org.txm.analec.rcp/src/visuAnalec/fichiers/FichiersGlozz.java	(revision 3438)
@@ -24,15 +24,15 @@
 	public static void convertirCorpusGlozz(final Corpus corpus) {
 		File repGlozz;
 		final File repJava;
-		if ((repGlozz = Fichiers.choisirRepertoire("Choix du répertoire Glozz")) == null)
+		if ((repGlozz = Fichiers.choisirRepertoire("Choix du dossier Glozz")) == null)
 			return;
-		if ((repJava = Fichiers.choisirRepertoire("Choix du répertoire Java")) == null)
+		if ((repJava = Fichiers.choisirRepertoire("Choix du dossier Java")) == null)
 			return;
 		if (!repJava.exists()) {
-			if (!GMessages.confirmationAction("Le répertoire spécifié n'existe pas."
+			if (!GMessages.confirmationAction("Le dossier spécifié n'existe pas."
 					+ " Voulez-vous le créer ?")) return;
 			if (!repJava.mkdir()) {
-				GMessages.impossibiliteAction("Echec de la création du répertoire");
+				GMessages.impossibiliteAction("Echec de la création du dossier");
 				return;
 			}
 		}
Index: TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/messages/messages_fr.properties
===================================================================
--- TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/messages/messages_fr.properties	(revision 3437)
+++ TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/messages/messages_fr.properties	(revision 3438)
@@ -17,7 +17,7 @@
 
 P0CorpusLoaded = {0} corpus chargé(s).
 
-SourceDirectoryPage_0 = Selection du répertoire des fichiers sources
+SourceDirectoryPage_0 = Selection du dossier des fichiers sources
 
 SourceDirectoryPage_1 = Sources
 
@@ -31,11 +31,11 @@
 
 SourceDirectoryPage_14 = Vérification du nom de corpus avec le pattern '[A-Z][-A-Z0-9]+': 
 
-SourceDirectoryPage_2 = Le répertoire des fichiers sources qui seront lu par le module d'import
+SourceDirectoryPage_2 = Le dossier des fichiers sources qui seront lu par le module d'import
 
 SourceDirectoryPage_3 = Répertoire des fichiers sources
 
-SourceDirectoryPage_5 = Cliquer pour sélectionner le répertoire des fichiers sources
+SourceDirectoryPage_5 = Cliquer pour sélectionner le dossier des fichiers sources
 
 SourceDirectoryPage_6 = Répertoire source à utiliser
 
@@ -363,7 +363,7 @@
 
 errorColonCorporaDirectoryDoesntExistColon = ** Erreur: le dossier 'corpora' n'existe pas : 
 
-errorColonCurrentGroovyScriptDirectoryDoesNotExistColon = ** Erreur : le répertoire du script Groovy courant n'existe pas : 
+errorColonCurrentGroovyScriptDirectoryDoesNotExistColon = ** Erreur : le dossier du script Groovy courant n'existe pas : 
 
 errorColonDeleteReturnedFalse = ** Erreur lors de la suppression
 
@@ -573,7 +573,7 @@
 
 installPathColonP0 = Chemin d''installation : {0}.
 
-installingPreviousCorpusFromP0 = Récupération des corpus préexistants de TXM {0} (depuis le répertoire {1})...
+installingPreviousCorpusFromP0 = Récupération des corpus préexistants de TXM {0} (depuis le dossier {1})...
 
 installingSampleCorpus = Installation des corpus exemples...
 
@@ -877,13 +877,13 @@
 
 selectAProperty = Sélectionner une propriété
 
-selectAnotherTXMCorporaToRestore = Sélectionner un autre répertoire "corpora" de corpus à récupérer...
+selectAnotherTXMCorporaToRestore = Sélectionner un autre dossier "corpora" de corpus à récupérer...
 
 selectColon = Sélectionner :
 
 selectTextId = Sélectionner un texte
 
-selectTheSourceDirectory = Sélectionner le répertoire des fichiers sources et nommer le corpus
+selectTheSourceDirectory = Sélectionner le dossier des fichiers sources et nommer le corpus
 
 selectThecorporaSetsToRestore = Sélectionnez les corpus à restaurer
 
@@ -1001,11 +1001,11 @@
 
 theNumberOfEditorsP0AndNumberOfInputsP1MustBeEqual = ** Erreur interne : le nombre d''éditeurs RCP ({0}) doit correspondre au nombre d''inputs ({1}).
 
-theP0CorpusDirectoryAlreadyExistsDoYouWantToReplaceIt = Le répertoire de corpus {0} existe déjà. Voulez-vous le remplacer ?
+theP0CorpusDirectoryAlreadyExistsDoYouWantToReplaceIt = Le dossier de corpus {0} existe déjà. Voulez-vous le remplacer ?
 
 theP0FileAlreadyExistsWouldYouLikeToReplaceIt = Le fichier {0} existe déjà. Voulez vous vraiment le remplacer ?
 
-theP0directoryNotABinaryCorpus = Le répertoire {0} n'est pas un corpus binaire.
+theP0directoryNotABinaryCorpus = Le dossier {0} n'est pas un corpus binaire.
 
 theP1GroovyScriptMustBeInTheP0Folder = Le script Groovy {1} doit être dans le dossier {0}.
 

Index: TXM/trunk/org.txm.core/src/java/org/txm/scripts/importer/Factiva2XmlTxm.groovy
===================================================================
--- TXM/trunk/org.txm.core/src/java/org/txm/scripts/importer/Factiva2XmlTxm.groovy	(revision 3437)
+++ TXM/trunk/org.txm.core/src/java/org/txm/scripts/importer/Factiva2XmlTxm.groovy	(revision 3438)
@@ -24,7 +24,7 @@
 	println "$rootDir : $fich_xml"
 
 	def ext = ".xml"
 	//def rep_final = rootDir.getAbsolutePath()+"/out" // le nom du répertoire dans lequel on va créer les fichiers txm
 
 	List<String> Balises = ["<baseLanguage>","<date>","<sourceName>","<name>","<name>"] // balises XML à détecter
 	List<String> FinBalises = ["</baseLanguage>","</date>","</sourceName>","</name>","</name>"]
@@ -59,17 +59,17 @@
 
 	def i = 1
 
-	println "Création du répertoire dans lequel on va mettre les fichiers finaux txm"
+	println "Création du dossier dans lequel on va mettre les fichiers finaux txm"
 	if (new File(rep_final).exists()) {
-		println "Le répertoire $rep_final existe"
+		println "Le dossier $rep_final existe"
 	}
 	else {
 		if (!new File(rep_final).mkdir()) {
-			println "Echec de la création du répertoire: $rep_final"
+			println "Echec de la création du dossier: $rep_final"
 			return
 		}
 		if (!new File(rep_final).canWrite()) {
-			println "Le répertoire '$rep_final' final est read-only"
+			println "Le dossier '$rep_final' final est read-only"
 			return
 		}
 	}
@@ -24,7 +24,7 @@
 
 	def ext = ".xml"
-	//def rep_final = rootDir.getAbsolutePath()+"/out" // le nom du répertoire dans lequel on va créer les fichiers txm
+	//def rep_final = rootDir.getAbsolutePath()+"/out" // le nom du dossier dans lequel on va créer les fichiers txm
 
 	List<String> Balises = ["<baseLanguage>","<date>","<sourceName>","<name>","<name>"] // balises XML à détecter